Package: qvalue
Type: Package
Title: Q-value estimation for false discovery rate control
Version: 2.44.0
Date: 2015-03-24
Authors@R: c(
  person(given = "John D.", family = "Storey",
         email = "jdstorey@princeton.edu", role = c("aut", "cre")),
  person(given = "Andrew J.", family = "Bass",
         email = "ajbass@emory.edu", role = "aut"),
  person(given = "Alan", family = "Dabney", role = "aut"),
  person(given = "David", family = "Robinson", role = "aut"),
  person(given = "Gregory", family = "Warnes", role = "ctb"))
Maintainer: John D. Storey <jstorey@princeton.edu>, Andrew J. Bass
 <ajbass@emory.edu>
biocViews: MultipleComparisons
Description: This package takes a list of p-values resulting from the
    simultaneous testing of many hypotheses and estimates their
    q-values and local FDR values. The q-value of a test measures
    the proportion of false positives incurred (called the false
    discovery rate) when that particular test is called significant.
    The local FDR measures the posterior probability the null
    hypothesis is true given the test's p-value. Various plots
    are automatically generated, allowing one to make sensible
    significance cut-offs. Several mathematical results have
    recently been shown on the conservative accuracy of the
    estimated q-values from this software. The software can be
    applied to problems in genomics, brain imaging, astrophysics,
    and data mining.
VignetteBuilder: knitr
Imports: splines, ggplot2, grid, reshape2
Suggests: knitr
Depends: R(>= 2.10)
URL: http://github.com/jdstorey/qvalue
License: LGPL
RoxygenNote: 5.0.1
git_url: https://git.bioconductor.org/packages/qvalue
git_branch: RELEASE_3_23
git_last_commit: ce7605b
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-29 00:02:46 UTC; biocbuild
Author: John D. Storey [aut, cre],
  Andrew J. Bass [aut],
  Alan Dabney [aut],
  David Robinson [aut],
  Gregory Warnes [ctb]
